@@ -3,24 +3,38 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 """Command line wrapper for the multiple alignment program MUSCLE.
-
-http://www.drive5.com/muscle/
-
-Citations:
-
-Edgar, Robert C. (2004), MUSCLE: multiple sequence alignment with high accuracy
-and high throughput, Nucleic Acids Research 32(5), 1792-97.
-
-Edgar, R.C. (2004) MUSCLE: a multiple sequence alignment method with reduced
-time and space complexity. BMC Bioinformatics 5(1): 113.
-
-Last checked against version: 3.7, briefly against 3.8
 """
 
 from Bio.Application import _Option, _Switch, AbstractCommandline
 
 class MuscleCommandline(AbstractCommandline):
-    """Command line wrapper for the multiple alignment program MUSCLE."""
+    r"""Command line wrapper for the multiple alignment program MUSCLE.
+
+    http://www.drive5.com/muscle/
+
+    Example:
+
+    >>> from Bio.Align.Applications import MuscleCommandline
+    >>> muscle_exe = r"C:\Program Files\Aligments\muscle3.8.31_i86win32.exe"
+    >>> in_file = r"C:\My Documents\unaligned.fasta"
+    >>> out_file = r"C:\My Documents\aligned.fasta"
+    >>> muscle_cline = MuscleCommandline(muscle_exe, input=in_file, out=out_file)
+    >>> print muscle_cline
+    C:\Program Files\Aligments\muscle3.8.31_i86win32.exe -in "C:\My Documents\unaligned.fasta" -out "C:\My Documents\aligned.fasta"
+
+    You would typically run the command line with muscle_cline() or via
+    the Python subprocess module, as described in the Biopython tutorial.
+
+    Citations:
+
+    Edgar, Robert C. (2004), MUSCLE: multiple sequence alignment with high
+    accuracy and high throughput, Nucleic Acids Research 32(5), 1792-97.
+
+    Edgar, R.C. (2004) MUSCLE: a multiple sequence alignment method with
+    reduced time and space complexity. BMC Bioinformatics 5(1): 113.
+
+    Last checked against version: 3.7, briefly against 3.8
+    """
     def __init__(self, cmd="muscle", **kwargs):
         CLUSTERING_ALGORITHMS   = ["upgma", "upgmb", "neighborjoining"]
         DISTANCE_MEASURES_ITER1 = ["kmer6_6", "kmer20_3", "kmer20_4", "kbit20_3",
@@ -35,132 +49,124 @@ class MuscleCommandline(AbstractCommandline):
         self.parameters = \
            [
             #Can't use "in" as the final alias as this is a reserved word in python:
-            _Option(["-in", "in", "input"], ["input", "file"],
-                    None, 0, "Input filename",
-                    0), #No equate
-            _Option(["-out", "out"], ["output", "file"],
-                    None, 0, "Output filename",
-                    0), #No equate
-            _Switch(["-diags", "diags"], ["input"],
+            _Option(["-in", "in", "input"],
+                    "Input filename",
+                    filename=True,
+                    equate=False),
+            _Option(["-out", "out"],
+                    "Output filename",
+                    filename=True,
+                    equate=False),
+            _Switch(["-diags", "diags"],
                     "Find diagonals (faster for similar sequences)"),
-            _Switch(["-profile", "profile"], ["input"],
+            _Switch(["-profile", "profile"],
                     "Perform a profile alignment"),
-            _Option(["-in1", "in1"], ["input", "file"],
-                    None, 0,
+            _Option(["-in1", "in1"],
                     "First input filename for profile alignment",
-                    0),
-            _Option(["-in2", "in2"], ["input", "file"],
-                    None, 0,
+                    filename=True,
+                    equate=False),
+            _Option(["-in2", "in2"],
                     "Second input filename for a profile alignment",
-                    0),
+                    filename=True,
+                    equate=False),
             #anchorspacing   Integer              32                 Minimum spacing between
-            _Option(["-anchorspacing", "anchorspacing"], ["input"],
-                    lambda x: isinstance(x, int),
-                    0,
+            _Option(["-anchorspacing", "anchorspacing"],
                     "Minimum spacing between anchor columns",
-                    0),
+                    checker_function=lambda x: isinstance(x, int),
+                    equate=False),
             #center          Floating point       [1]                Center parameter.
             #                                                        Should be negative.
-            _Option(["-center", "center"], ["input"],
-                    lambda x: isinstance(x, float),
-                    0,
+            _Option(["-center", "center"],
                     "Center parameter - should be negative",
-                    0),
+                    checker_function=lambda x: isinstance(x, float),
+                    equate=False),
             #cluster1        upgma                upgmb              Clustering method.
-            _Option(["-cluster1", "cluster1"], ["input"],
-                    lambda x: x in CLUSTERING_ALGORITHMS, 0,
+            _Option(["-cluster1", "cluster1"],
                     "Clustering method used in iteration 1",
-                    0),
+                    checker_function=lambda x: x in CLUSTERING_ALGORITHMS,
+                    equate=False),
             #cluster2        upgmb                                   cluster1 is used in
             #                neighborjoining                         iteration 1 and 2,
             #                                                        cluster2 in later
             #                                                        iterations.
-            _Option(["-cluster2", "cluster2"], ["input"],
-                    lambda x: x in CLUSTERING_ALGORITHMS, 0,
+            _Option(["-cluster2", "cluster2"],
                     "Clustering method used in iteration 2",
-                    0),
+                    checker_function=lambda x: x in CLUSTERING_ALGORITHMS,
+                    equate=False),
             #diaglength      Integer              24                 Minimum length of
             #                                                        diagonal.
-            _Option(["-diaglength", "diaglength"], ["input"],
-                    lambda x: isinstance(x, int),
-                    0,
+            _Option(["-diaglength", "diaglength"],
                     "Minimum length of diagonal",
-                    0),
+                    checker_function=lambda x: isinstance(x, int),
+                    equate=True),
             #diagmargin      Integer              5                  Discard this many
             #                                                        positions at ends of
             #                                                        diagonal.
-            _Option(["-diagmargin", "diagmargin"], ["input"],
-                    lambda x: isinstance(x, int),
-                    0,
+            _Option(["-diagmargin", "diagmargin"],
                     "Discard this many positions at ends of diagonal",
-                    0),
+                    checker_function=lambda x: isinstance(x, int),
+                    equate=False),
             #distance1       kmer6_6              Kmer6_6 (amino) or Distance measure for
             #                kmer20_3             Kmer4_6 (nucleo)   iteration 1.
             #                kmer20_4
             #                kbit20_3
             #                kmer4_6
-            _Option(["-distance1", "distance1"], ["input"],
-                    lambda x: x in DISTANCE_MEASURES_ITER1,
-                    0,
+            _Option(["-distance1", "distance1"],
                     "Distance measure for iteration 1",
-                    0),
+                    checker_function=lambda x: x in DISTANCE_MEASURES_ITER1,
+                    equate=False),
             #distance2       kmer6_6              pctid_kimura       Distance measure for
             #                kmer20_3                                iterations 2, 3 ...
             #                kmer20_4
             #                kbit20_3
             #                pctid_kimura
             #                pctid_log
-            _Option(["-distance2", "distance2"], ["input"],
-                    lambda x: x in DISTANCE_MEASURES_ITER2,
-                    0,
+            _Option(["-distance2", "distance2"],
                     "Distance measure for iteration 2",
-                    0),
+                    checker_function=lambda x: x in DISTANCE_MEASURES_ITER2,
+                    equate=False),
             #gapopen         Floating point       [1]                The gap open score.
             #                                                        Must be negative.
-            _Option(["-gapopen", "gapopen"], ["input"],
-                    lambda x: isinstance(x, float),
-                    0,
+            _Option(["-gapopen", "gapopen"],
                     "Gap open score - negative number",
-                    0),
+                    checker_function=lambda x: isinstance(x, float),
+                    equate=False),
             #hydro           Integer              5                  Window size for
             #                                                        determining whether a
             #                                                        region is hydrophobic.
-            _Option(["-hydro", "hydro"], ["input"],
-                    lambda x: isinstance(x, int),
-                    0,
+            _Option(["-hydro", "hydro"],
                     "Window size for hydrophobic region",
-                    0),
+                    checker_function=lambda x: isinstance(x, int),
+                    equate=False),
             #hydrofactor     Floating point       1.2                Multiplier for gap
             #                                                        open/close penalties in
             #                                                        hydrophobic regions.
-            _Option(["-hydrofactor", "hydrofactor"], ["input"],
-                    lambda x: isinstance(x, float),
-                    0,
+            _Option(["-hydrofactor", "hydrofactor"],
                     "Multiplier for gap penalties in hydrophobic regions",
-                    0),
+                    checker_function=lambda x: isinstance(x, float),
+                    equate=False),
             #log             File name            None.              Log file name (delete
             #                                                        existing file).
-            _Option(["-log", "log"], ["output", "file"],
-                    None, 0,
+            _Option(["-log", "log"],
                     "Log file name",
-                    0),
+                    filename=True,
+                    equate=False),
             #loga            File name            None.              Log file name (append
             #                                                        to existing file).
-            _Option(["-loga", "loga"], ["output", "file"],
-                    None, 0,
+            _Option(["-loga", "loga"],
                     "Log file name (append to existing file)",
-                    0),
+                    filename=True,
+                    equate=False),
             #maxdiagbreak    Integer              1                  Maximum distance
             #                                                        between two diagonals
             #                                                        that allows them to
             #                                                        merge into one
             #                                                        diagonal.
-            _Option(["-maxdiagbreak", "maxdiagbreak"], ["input"],
-                    lambda x: isinstance(x, int),
-                    0,
-                    "Maximum distance between two diagonals that allows " + \
+            _Option(["-maxdiagbreak", "maxdiagbreak"],
+                    "Maximum distance between two diagonals that allows "
                     "them to merge into one diagonal",
-                    0),
+                    checker_function=lambda x: isinstance(x, int),
+                    equate=False),
             #maxhours        Floating point       None.              Maximum time to run in
             #                                                        hours. The actual time
             #                                                        may exceed the
@@ -169,43 +175,38 @@ class MuscleCommandline(AbstractCommandline):
             #                                                        are allowed, so 1.5
             #                                                        means one hour and 30
             #                                                        minutes.
-            _Option(["-maxhours", "maxhours"], ["input"],
-                    lambda x: isinstance(x, float),
-                    0,
+            _Option(["-maxhours", "maxhours"],
                     "Maximum time to run in hours",
-                    0),
+                    checker_function=lambda x: isinstance(x, float),
+                    equate=False),
             #maxiters        Integer 1, 2 ...     16                 Maximum number of
             #                                                        iterations.
-            _Option(["-maxiters", "maxiters"], ["input"],
-                    lambda x: isinstance(x, int),
-                    0,
+            _Option(["-maxiters", "maxiters"],
                     "Maximum number of iterations",
-                    0),
+                    checker_function=lambda x: isinstance(x, int),
+                    equate=False),
             #maxtrees        Integer              1                  Maximum number of new
             #                                                        trees to build in
             #                                                        iteration 2.
-            _Option(["-maxtrees", "maxtrees"], ["input"],
-                    lambda x: isinstance(x, int),
-                    0,
+            _Option(["-maxtrees", "maxtrees"],
                     "Maximum number of trees to build in iteration 2",
-                    0),
+                    checker_function=lambda x: isinstance(x, int),
+                    equate=False),
             #minbestcolscore Floating point       [1]                Minimum score a column
             #                                                        must have to be an
             #                                                        anchor.
-            _Option(["-minbestcolscore", "minbestcolscore"], ["input"],
-                    lambda x: isinstance(x, float),
-                    0,
+            _Option(["-minbestcolscore", "minbestcolscore"],
                     "Minimum score a column must have to be an anchor",
-                    0),
+                    checker_function=lambda x: isinstance(x, float),
+                    equate=False),
             #minsmoothscore  Floating point       [1]                Minimum smoothed score
             #                                                        a column must have to
             #                                                        be an anchor.
-            _Option(["-minsmoothscore", "minsmoothscore"], ["input"],
-                    lambda x: isinstance(x, float),
-                    0,
-                    "Minimum smoothed score a column must have to " + \
+            _Option(["-minsmoothscore", "minsmoothscore"],
+                    "Minimum smoothed score a column must have to "
                     "be an anchor",
-                    0),
+                    checker_function=lambda x: isinstance(x, float),
+                    equate=False),
             #objscore        sp                   spm                Objective score used by
             #                ps                                      tree dependent
             #                dp                                      refinement.
@@ -219,49 +220,43 @@ class MuscleCommandline(AbstractCommandline):
             #                                                        ps=average profile-
             #                                                        sequence score.
             #                                                        xp=cross profile score.
-            _Option(["-objscore", "objscore"], ["input"],
-                    lambda x: x in OBJECTIVE_SCORES,
-                    0,
+            _Option(["-objscore", "objscore"],
                     "Objective score used by tree dependent refinement",
-                    0),
+                    checker_function=lambda x: x in OBJECTIVE_SCORES,
+                    equate=False),
             #root1           pseudo               psuedo             Method used to root
-            _Option(["-root1", "root1"], ["input"],
-                    lambda x: x in TREE_ROOT_METHODS,
-                    0,
+            _Option(["-root1", "root1"],
                     "Method used to root tree in iteration 1",
-                    0),
+                    checker_function=lambda x: x in TREE_ROOT_METHODS,
+                    equate=False),
             #root2           midlongestspan                          tree; root1 is used in
             #                minavgleafdist                          iteration 1 and 2,
             #                                                        root2 in later
             #                                                        iterations.
-            _Option(["-root2", "root2"], ["input"],
-                    lambda x: x in TREE_ROOT_METHODS,
-                    0,
+            _Option(["-root2", "root2"],
                     "Method used to root tree in iteration 2",
-                    0),
+                    checker_function=lambda x: x in TREE_ROOT_METHODS,
+                    equate=False),
             #seqtype         protein              auto               Sequence type.
             #                nucleo
             #                auto
-            _Option(["-seqtype", "seqtype"], ["input"],
-                    lambda x: x in SEQUENCE_TYPES,
-                    0,
+            _Option(["-seqtype", "seqtype"],
                     "Sequence type",
-                    0),
+                    checker_function=lambda x: x in SEQUENCE_TYPES,
+                    equate=False),
             #smoothscoreceil Floating point       [1]                Maximum value of column
             #                                                        score for smoothing
             #                                                        purposes.
-            _Option(["-smoothscoreceil", "smoothscoreceil"], ["input"],
-                    lambda x: isinstance(x, float),
-                    0,
+            _Option(["-smoothscoreceil", "smoothscoreceil"],
                     "Maximum value of column score for smoothing",
-                    0),
+                    checker_function=lambda x: isinstance(x, float),
+                    equate=False),
             #smoothwindow    Integer              7                  Window used for anchor
             #                                                        column smoothing.
-            _Option(["-smoothwindow", "smoothwindow"], ["input"],
-                    lambda x: isinstance(x, int),
-                    0,
+            _Option(["-smoothwindow", "smoothwindow"],
                     "Window used for anchor column smoothing",
-                    0),
+                    checker_function=lambda x: isinstance(x, int),
+                    equate=False),
             #SUEFF           Floating point value 0.1                Constant used in UPGMB
             #                between 0 and 1.                        clustering. Determines
             #                                                        the relative fraction
@@ -269,30 +264,26 @@ class MuscleCommandline(AbstractCommandline):
             #                                                        (SUEFF) vs. nearest-
             #                                                        neighbor linkage (1
             #                                                        SUEFF).
-            _Option(["-sueff", "sueff"], ["input"],
-                    lambda x: isinstance(x, float),
-                    0,
+            _Option(["-sueff", "sueff"],
                     "Constant used in UPGMB clustering",
-                    0),
+                    checker_function=lambda x: isinstance(x, float),
+                    equate=False),
             #tree1           File name            None               Save tree produced in
-            _Option(["-tree1", "tree1"], ["input"],
-                    None, 0,
+            _Option(["-tree1", "tree1"],
                     "Save Newick tree from iteration 1",
-                    0),
+                    equate=False),
             #tree2                                                   first or second
             #                                                        iteration to given file
             #                                                        in Newick (Phylip-
             #                                                        compatible) format.
-            _Option(["-tree2", "tree2"], ["input"],
-                    None, 0,
+            _Option(["-tree2", "tree2"],
                     "Save Newick tree from iteration 2",
-                    0),
+                    equate=False),
             #weight1         none                 clustalw           Sequence weighting
-            _Option(["-weight1", "weight1"], ["input"],
-                    lambda x: x in WEIGHTING_SCHEMES,
-                    0,
+            _Option(["-weight1", "weight1"],
                     "Weighting scheme used in iteration 1",
-                    0),
+                    checker_function=lambda x: x in WEIGHTING_SCHEMES,
+                    equate=False),
             #weight2         henikoff                                scheme.
             #                henikoffpb                              weight1 is used in
             #                gsc                                     iterations 1 and 2.
@@ -311,11 +302,10 @@ class MuscleCommandline(AbstractCommandline):
             #                                                        method.
             #                                                        threeway=Gotoh three-
             #                                                        way method.
-            _Option(["-weight2", "weight2"], ["input"],
-                    lambda x: x in WEIGHTING_SCHEMES,
-                    0,
+            _Option(["-weight2", "weight2"],
                     "Weighting scheme used in iteration 2",
-                    0),
+                    checker_function=lambda x: x in WEIGHTING_SCHEMES,
+                    equate=False),
             #################### FORMATS #######################################
             # Multiple formats can be specified on the command line
             # If -msf appears it will be used regardless of other formats
@@ -328,85 +318,83 @@ class MuscleCommandline(AbstractCommandline):
             # will html be used. I kid ye not.
             #clw                no              Write output in CLUSTALW format (default is
             #                                   FASTA).
-            _Switch(["-clw", "clw"], ["input"],
+            _Switch(["-clw", "clw"],
                     "Write output in CLUSTALW format (with a MUSCLE header)"),
             #clwstrict          no              Write output in CLUSTALW format with the
             #                                   "CLUSTAL W (1.81)" header rather than the
             #                                   MUSCLE version. This is useful when a post-
             #                                   processing step is picky about the file
             #                                   header.
-            _Switch(["-clwstrict", "clwstrict"], ["input"],
+            _Switch(["-clwstrict", "clwstrict"],
                     "Write output in CLUSTALW format with version 1.81 header"),
             #fasta              yes             Write output in FASTA format. Alternatives
             #                                   include clw,
             #                                   clwstrict, msf and html.
-            _Switch(["-fasta", "fasta"], ["input"],
+            _Switch(["-fasta", "fasta"],
                     "Write output in FASTA format"),
             #html               no              Write output in HTML format (default is
             #                                   FASTA).
-            _Switch(["-html", "html"], ["input"],
+            _Switch(["-html", "html"],
                     "Write output in HTML format"),
             #msf                no              Write output in MSF format (default is
             #                                   FASTA).
-            _Switch(["-msf", "msf"], ["input"],
+            _Switch(["-msf", "msf"],
                     "Write output in MSF format"),
             #Phylip interleaved - undocumented as of 3.7
-            _Switch(["-phyi", "phyi"], ["input"],
+            _Switch(["-phyi", "phyi"],
                     "Write output in PHYLIP interleaved format"),
             #Phylip sequential - undocumented as of 3.7
-            _Switch(["-phys", "phys"], ["input"],
+            _Switch(["-phys", "phys"],
                     "Write output in PHYLIP sequential format"),
             ################## Additional specified output files #########
-            _Option(["-phyiout", "phyiout"], ["output", "file"],
-                    None, 0,
+            _Option(["-phyiout", "phyiout"],
                     "Write PHYLIP interleaved output to specified filename",
-                    0), #No equate
-            _Option(["-physout", "physout"], ["output", "file"],
-                    None, 0,
-                    "Write PHYLIP sequential format to specified filename",
-                    0), #No equate
-            _Option(["-htmlout", "htmlout"], ["output", "file"],
-                    None, 0,
-                    "Write HTML output to specified filename",
-                    0), #No equate
-            _Option(["-clwout", "clwout"], ["output", "file"],
-                    None, 0,
+                    filename=True,
+                    equate=False),
+            _Option(["-physout", "physout"],"Write PHYLIP sequential format to specified filename",
+                    filename=True,
+                    equate=False),
+            _Option(["-htmlout", "htmlout"],"Write HTML output to specified filename",
+                    filename=True,
+                    equate=False),
+            _Option(["-clwout", "clwout"],
                     "Write CLUSTALW output (with MUSCLE header) to specified "
                     "filename",
-                    0), #No equate
-            _Option(["-clwstrictout", "clwstrictout"], ["output", "file"],
-                    None, 0,
+                    filename=True,
+                    equate=False),
+            _Option(["-clwstrictout", "clwstrictout"],
                     "Write CLUSTALW output (with version 1.81 header) to "
                     "specified filename",
-                    0), #No equate
-            _Option(["-msfout", "msfout"], ["output", "file"],
-                    None, 0,
+                    filename=True,
+                    equate=False),
+            _Option(["-msfout", "msfout"],
                     "Write MSF format output to specified filename",
-                    0), #No equate
-            _Option(["-fastaout", "fastaout"], ["output", "file"],
-                    None, 0,
+                    filename=True,
+                    equate=False),
+            _Option(["-fastaout", "fastaout"],
                     "Write FASTA format output to specified filename",
-                    0), #No equate
+                    filename=True,
+                    equate=False),
             ############## END FORMATS ###################################
             #anchors            yes             Use anchor optimization in tree dependent
             #                                   refinement iterations.
-            _Switch(["-anchors", "anchors"], ["input"],
-                    "Use anchor optimisation in tree dependent " + \
+            _Switch(["-anchors", "anchors"],
+                    "Use anchor optimisation in tree dependent "
                     "refinement iterations"),
             #noanchors          no              Disable anchor optimization. Default is
             #                                   anchors.
-            _Switch(["-noanchors", "noanchors"], ["input"],
-                    "Do not use anchor optimisation in tree dependent " + \
+            _Switch(["-noanchors", "noanchors"],
+                    "Do not use anchor optimisation in tree dependent "
                     "refinement iterations"),
             #group              yes             Group similar sequences together in the
             #                                   output. This is the default. See also
             #                                   stable.
-            _Switch(["-group", "group"], ["input"],
+            _Switch(["-group", "group"],
                     "Group similar sequences in output"),
             #stable             no              Preserve input order of sequences in output
             #                                   file. Default is to group sequences by
             #                                   similarity (group).
-            _Switch(["-stable", "stable"], ["input"],
+            _Switch(["-stable", "stable"],
                     "Do not group similar sequences in output (not supported in v3.8)"),
             ############## log-expectation profile score ######################
             # One of either -le, -sp, or -sv
@@ -419,38 +407,38 @@ class MuscleCommandline(AbstractCommandline):
             #le                 maybe           Use log-expectation profile score (VTML240).
             #                                    Alternatives are to use sp or sv. This is
             #                                    the default for amino acid sequences.
-            _Switch(["-le", "le"], ["input"],
+            _Switch(["-le", "le"],
                     "Use log-expectation profile score (VTML240)"),
             #sv                 no              Use sum-of-pairs profile score (VTML240).
             #                                   Default is le.
-            _Switch(["-sv", "sv"], ["input"],
+            _Switch(["-sv", "sv"],
                     "Use sum-of-pairs profile score (VTML240)"),
             #sp                 no              Use sum-of-pairs protein profile score
             #                                   (PAM200). Default is le.
-            _Switch(["-sp", "sp"], ["input"],
+            _Switch(["-sp", "sp"],
                     "Use sum-of-pairs protein profile score (PAM200)"),
             #spn                maybe           Use sum-of-pairs nucleotide profile score
             #                                   (BLASTZ parameters). This is the only option
             #                                   for nucleotides, and is therefore the
             #                                   default.
-            _Switch(["-spn", "spn"], ["input"],
+            _Switch(["-spn", "spn"],
                     "Use sum-of-pairs protein nucleotide profile score"),
             ############## END log-expectation profile score ######################
             #quiet              no              Do not display progress messages.
-            _Switch(["-quiet", "quiet"], ["input"],
+            _Switch(["-quiet", "quiet"],
                     "Use sum-of-pairs protein nucleotide profile score"),
             #refine             no              Input file is already aligned, skip first
             #                                   two iterations and begin tree dependent
             #                                   refinement.
-            _Switch(["-refine", "refine"], ["input"],
+            _Switch(["-refine", "refine"],
                     "Only do tree dependent refinement"),
             #core               yes in muscle,  Do not catch exceptions.
             #                   no in muscled.
-            _Switch(["-core", "core"], ["input"],
+            _Switch(["-core", "core"],
                     "Catch exceptions"),
             #nocore             no in muscle,   Catch exceptions and give an error message
             #                   yes in muscled. if possible.
-            _Switch(["-nocore", "nocore"], ["input"],
+            _Switch(["-nocore", "nocore"],
                     "Do not catch exceptions"),
             #termgapsfull       no              Terminal gaps penalized with full penalty.
             #                                   [1] Not fully supported in this version.
@@ -465,10 +453,20 @@ class MuscleCommandline(AbstractCommandline):
             #                                   [1] Not fully supported in this version.
             #verbose            no              Write parameter settings and progress
             #                                   messages to log file.
-            _Switch(["-verbose", "verbose"], ["input"],
+            _Switch(["-verbose", "verbose"],
                     "Write parameter settings and progress"),
             #version            no              Write version string to stdout and exit.
-            _Switch(["-version", "version"], ["input"],
+            _Switch(["-version", "version"],
                     "Write version string to stdout and exit"),
            ]
         AbstractCommandline.__init__(self, cmd, **kwargs)
+
+def _test():
+    """Run the module's doctests (PRIVATE)."""
+    print "Runing MUSCLE doctests..."
+    import doctest
+    doctest.testmod()
+    print "Done"
+
+if __name__ == "__main__":
+    _test()
