@@ -539,27 +539,31 @@ class MultipleSeqAlignment(_Alignment):
         self._records.sort(key = lambda r: r.id)
 
     def get_column(self, col):
-        """Returns a string containing a given column (OBSOLETE).
+        """Returns a string containing a given column (DEPRECATED).
 
         This is a method provided for backwards compatibility with the old
-        Bio.Align.Generic.Alignment object. You are encouraged to use the
-        slice notation instead.
+        Bio.Align.Generic.Alignment object. Please use the slice notation
+        instead, since get_column is likely to be removed in a future release
+        of Biopython..
         """
         import warnings
-        warnings.warn("This is a method provided for backwards compatibility with the old Bio.Align.Generic.Alignment object. You are encouraged to use the slice notation instead.", PendingDeprecationWarning)
+        import Bio
+        warnings.warn("This method is deprecated and is provided for backwards compatibility with the old Bio.Align.Generic.Alignment object. Please use the slice notation instead, as get_column is likely to be removed in a future release of Biopython.", Bio.BiopythonDeprecationWarning)
         return _Alignment.get_column(self, col)
 
     def add_sequence(self, descriptor, sequence, start = None, end = None,
                      weight = 1.0):
-        """Add a sequence to the alignment (OBSOLETE).
+        """Add a sequence to the alignment (DEPRECATED).
 
         The start, end, and weight arguments are not supported! This method
         only provides limited backwards compatibility with the old
-        Bio.Align.Generic.Alignment object. You are encouraged to use the
-        append method with a SeqRecord instead.
+        Bio.Align.Generic.Alignment object. Please use the append method with
+        a SeqRecord instead, since add_sequence is likely to be removed in a
+        future release of Biopython.
         """
         import warnings
-        warnings.warn("The start, end, and weight arguments are not supported! This method only provides limited backwards compatibility with the old Bio.Align.Generic.Alignment object. You are encouraged to use the append method with a SeqRecord instead.", PendingDeprecationWarning)
+        import Bio
+        warnings.warn("The start, end, and weight arguments are not supported! This method only provides limited backwards compatibility with the old Bio.Align.Generic.Alignment object. Please use the append method with a SeqRecord instead, as the add_sequence method is likely to be removed in a future release of Biopython.", Bio.BiopythonDeprecationWarning)
         #Should we handle start/end/strand information somehow? What for?
         #TODO - Should we handle weights somehow? See also AlignInfo code...
         if start is not None or end is not None or weight != 1.0:
