@@ -50,7 +50,7 @@ class GeneralPointCrossover:
         self._crossover_prob = crossover_prob
 
         self._sym     = points % 2 # odd n, gets a symmetry flag
-        self._npoints = (points + self._sym)/2 # (N or N+1)/2
+        self._npoints = (points + self._sym)//2 # (N or N+1)//2
     
     def do_crossover(self, org_1, org_2):
         """Potentially do a crossover between the two organisms.
