@@ -12,7 +12,6 @@ motifs or signatures.
 """
 # standard modules
 import random
-import string
 import re
 
 # biopython
@@ -139,9 +138,7 @@ class Schema:
     def all_unambiguous(self):
         """Return a listing of all unambiguous letters allowed in motifs.
         """
-        all_letters = self._ambiguity_info.keys()
-        all_letters.sort()
-
+        all_letters = sorted(self._ambiguity_info)
         unambig_letters = []
 
         for letter in all_letters:
@@ -251,7 +248,7 @@ class GeneticAlgorithmFinder:
             # convert the Genome from a MutableSeq to a Seq so that
             # the schemas are just strings (and not array("c")s)
             seq_genome = org.genome.toseq()
-            schema_info[seq_genome.data] = org.fitness
+            schema_info[seq_genome.tostring()] = org.fitness
 
         return PatternRepository(schema_info)
 
@@ -292,20 +289,20 @@ class DifferentialSchemaFitness:
         """
         # convert the genome into a string
         seq_motif = genome.toseq()
-        motif = seq_motif.data
+        motif = seq_motif.tostring()
         
         # get the counts in the positive examples
         num_pos = 0
         for seq_record in self._pos_seqs:
             cur_counts = self._schema_eval.num_matches(motif,
-                                                      seq_record.seq.data)
+                                                      seq_record.seq.tostring())
             num_pos += cur_counts
 
         # get the counts in the negative examples
         num_neg = 0
         for seq_record in self._neg_seqs:
             cur_counts = self._schema_eval.num_matches(motif,
-                                                      seq_record.seq.data)
+                                                      seq_record.seq.tostring())
 
             num_neg += cur_counts
 
@@ -352,13 +349,13 @@ class MostCountSchemaFitness:
         """
         # convert the genome into a string
         seq_motif = genome.toseq()
-        motif = seq_motif.data
+        motif = seq_motif.tostring()
         
         # find the number of times the genome matches
         num_times = 0
         for seq_record in self._records:
             cur_counts = self._evaluator.num_matches(motif,
-                                                     seq_record.seq.data)
+                                                     seq_record.seq.tostring())
             num_times += cur_counts
 
         return num_times
@@ -513,7 +510,7 @@ class SchemaCoder:
         schema_counts = []
 
         for schema in self._schemas:
-            num_counts = self._converter.num_matches(schema, sequence.data)
+            num_counts = self._converter.num_matches(schema, sequence.tostring())
             schema_counts.append(num_counts)
 
         # normalize the counts to go between zero and one
@@ -708,7 +705,7 @@ class SchemaFactory:
                     break
 
         # convert the schema back to a string
-        new_schema = string.join(new_schema_list, '')
+        new_schema = ''.join(new_schema_list)
 
         # get the motifs that the schema matches
         matched_motifs = []
