@@ -5,10 +5,10 @@
 
 from copy import copy
 
-from PDBExceptions import PDBConstructionException, PDBException
+from Bio.PDB.PDBExceptions import PDBConstructionException, PDBException
+
+"""Base class for Residue, Chain, Model and Structure classes.
 
-__doc__="""
-Base class for Residue, Chain, Model and Structure classes. 
 It is a simple container class, with list and dictionary like properties.
 """
 
@@ -37,6 +37,10 @@ class Entity:
         "Return the child with given id."
         return self.child_dict[id]
 
+    def __delitem__(self, id):
+        "Remove a child."
+        return self.detach_child(id)
+
     def __iter__(self):
         "Iterate over children."
         for child in self.child_list:
@@ -68,8 +72,7 @@ class Entity:
         child=self.child_dict[id] 
         child.detach_parent()
         del self.child_dict[id]
-        self.child_list=self.child_dict.values()
-        self.child_list.sort(self._sort)
+        self.child_list.remove(child)
 
     def add(self, entity):
         "Add a child to the Entity."
@@ -79,7 +82,6 @@ class Entity:
                 "%s defined twice" % str(entity_id))
         entity.set_parent(self)
         self.child_list.append(entity)
-        #self.child_list.sort(self._sort)
         self.child_dict[entity_id]=entity
     
     def get_iterator(self):
@@ -92,8 +94,8 @@ class Entity:
         return copy(self.child_list)
 
     def has_id(self, id):
-        "Return 1 if a child with given id exists, otherwise 0."
-        return self.child_dict.has_key(id)
+        """True if a child with given id exists."""
+        return (id in self.child_dict)
 
     def get_parent(self):
         "Return the parent Entity object."
@@ -120,7 +122,7 @@ class Entity:
         Residue with id (" ", 10, "A")
 
         The Residue id indicates that the residue is not a hetero-residue 
-        (or a water) beacuse it has a blanc hetero field, that its sequence 
+        (or a water) beacuse it has a blank hetero field, that its sequence 
         identifier is 10 and its insertion code "A".
         """
         if self.full_id==None:
@@ -163,10 +165,28 @@ class DisorderedEntityWrapper:
             raise AttributeError
         return getattr(self.selected_child, method)
 
+    def __getitem__(self, id):
+        "Return the child with the given id."
+        return self.selected_child[id]
+
+    # XXX Why doesn't this forward to selected_child?
+    # (NB: setitem was here before getitem, iter, len, sub)
     def __setitem__(self, id, child):
         "Add a child, associated with a certain id."
         self.child_dict[id]=child
 
+    def __iter__(self):
+        "Return the number of children."
+        return iter(self.selected_child)
+
+    def __len__(self):
+        "Return the number of children."
+        return len(self.selected_child)
+
+    def __sub__(self, other):
+        """Subtraction with another object."""
+        return self.selected_child - other
+
     # Public methods    
 
     def get_id(self):
@@ -174,8 +194,8 @@ class DisorderedEntityWrapper:
         return self.id
 
     def disordered_has_id(self, id):
-        "Return 1 if there is an object present associated with this id."
-        return self.child_dict.has_key(id)
+        """True if there is an object present associated with this id."""
+        return (id in self.child_dict)
 
     def detach_parent(self):
         "Detach the parent"
