@@ -5,6 +5,7 @@
 
 """Output of PDB files."""
 
+from Bio.Data.IUPACData import atom_weights # Allowed Elements
 
 _ATOM_FORMAT_STRING="%s%5i %-4s%c%3s %c%4i%c   %8.3f%8.3f%8.3f%6.2f%6.2f      %4s%2s%2s\n"
 
@@ -72,10 +73,9 @@ class PDBIO:
         else:
             record_type="ATOM  "
         if atom.element:
-            #TODO - Check against a list of allowed elements?
             element = atom.element.strip().upper()
-            if len(atom.element) > 2 or not element.isalpha():
-                raise ValueError("Unrecognised element %s" % repr(atom.element))
+            if element.capitalize() not in atom_weights:
+                raise ValueError("Unrecognised element %r" % atom.element)
             element = element.rjust(2)
         else:
             element = "  "
