@@ -3,14 +3,32 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
+"""Wrappers for PSEA, a program for secondary structure assignment.
+
+See this citation for P-SEA, PMID: 9183534
+
+Labesse G, Colloc'h N, Pothier J, Mornon J-P:  P-SEA: a new efficient
+assignment of secondary structure from C_alpha.
+Comput Appl Biosci 1997 , 13:291-295
+
+ftp://ftp.lmcp.jussieu.fr/pub/sincris/software/protein/p-sea/
+"""
 
 import os
-from Bio.PDB import *
+
+from Bio.PDB.Polypeptide import is_aa
 
 
 def run_psea(fname):
-    """
-    Run PSEA and return output filename.
+    """Run PSEA and return output filename.
+    
+    Note that this assumes the P-SEA binary is called "psea" and that it is
+    on the path.
+    
+    Note that P-SEA will write an output file in the current directory using
+    the input filename with extension ".sea".
+    
+    Note that P-SEA will write output to the terminal while run.
     """
     os.system("psea "+fname)
     last=fname.split("/")[-1]
@@ -18,9 +36,7 @@ def run_psea(fname):
     return base+".sea"
 
 def psea(pname):
-    """
-    Parse PSEA output file.
-    """
+    """Parse PSEA output file."""
     fname=run_psea(pname)
     start=0
     ss=""
@@ -38,9 +54,7 @@ def psea(pname):
     return ss
 
 def psea2HEC(pseq):
-    """
-    Translate PSEA secondary structure string into HEC.
-    """
+    """Translate PSEA secondary structure string into HEC."""
     seq=[]
     for ss in pseq:
         if ss=="a":
@@ -52,7 +66,8 @@ def psea2HEC(pseq):
         seq.append(n)
     return seq
 
-def annotate(m, ss_seq): 
+def annotate(m, ss_seq):
+    """Apply seconardary structure information to residues in model."""
     c=m.get_list()[0]
     all=c.get_list()
     residues=[]
@@ -84,7 +99,7 @@ class PSEA:
 if __name__=="__main__":
 
     import sys
-    from Bio.PDB import *
+    from Bio.PDB import PDBParser
 
     # Parse PDB file
     p=PDBParser()
