@@ -169,54 +169,27 @@ class _GenePopCommandline(AbstractCommandline):
     def __init__(self, genepop_dir=None, cmd='Genepop', **kwargs):
         self.parameters = [
                 _Argument(["command"],
-                    ["INTEGER(.INTEGER)*"],
-                    None,
-                    True,
-                    "GenePop option to be called"),
+                    "GenePop option to be called",
+                    is_required=True),
                 _Argument(["mode"],
-                    ["Dont touch this"],
-                    None,
-                    True,
-                    "Should allways be batch"),
+                    "Should allways be batch",
+                    is_required=True),
                 _Argument(["input"],
-                    ["input"],
-                    None,
-                    True,
-                    "Input file"),
+                    "Input file",
+                    is_required=True),
                 _Argument(["Dememorization"],
-                    ["input"],
-                    None,
-                    False,
                     "Dememorization step"),
                 _Argument(["BatchNumber"],
-                    ["input"],
-                    None,
-                    False,
                     "Number of MCMC batches"),
                 _Argument(["BatchLength"],
-                    ["input"],
-                    None,
-                    False,
                     "Length of MCMC chains"),
                 _Argument(["HWtests"],
-                    ["input"],
-                    None,
-                    False,
                     "Enumeration or MCMC"),
                 _Argument(["IsolBDstatistic"],
-                    ["input"],
-                    None,
-                    False,
                     "IBD statistic (a or e)"),
                 _Argument(["MinimalDistance"],
-                    ["input"],
-                    None,
-                    False,
                     "Minimal IBD distance"),
                 _Argument(["GeographicScale"],
-                    ["input"],
-                    None,
-                    False,
                     "Log or Linear"),
         ]
         AbstractCommandline.__init__(self, cmd, **kwargs)
