@@ -1,4 +1,6 @@
 # Copyright 2001 by Gavin E. Crooks.  All rights reserved.
+# Modifications Copyright 2010 Jeffrey Finkelstein. All rights reserved.
+#
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
@@ -21,7 +23,7 @@ from Residues import *
 
 
 class Record:
-    """Holds information for one SCOP domain
+    """Holds information for one SCOP domain.
 
     sid         --  SCOP identifier. e.g. d1danl2
 
@@ -31,16 +33,18 @@ class Record:
 
     sunid       --  SCOP unique identifier for this domain
 
-    hierarchy   --  A sequence of tuples (nodetype, sunid) describing the
-                    location of this domain in the SCOP hierarchy.
-                    See the Scop module for a description of nodetypes.
+    hierarchy   --  A dictionary, keys are nodetype, values are sunid,
+                    describing the location of this domain in the SCOP
+                    hierarchy. See the Scop module for a description of
+                    nodetypes. This used to be a list of (key,value) tuples
+                    in older versions of Biopython (see Bug 3109).
     """
     def __init__(self, line=None):
         self.sid = ''
         self.residues = None 
         self.sccs = ''
         self.sunid =''
-        self.hierarchy = []
+        self.hierarchy = {}
         if line:
             self._process(line)
         
@@ -57,8 +61,7 @@ class Record:
         
         for ht in hierarchy.split(","):
             key, value = ht.split('=')
-            value = int(value)
-            self.hierarchy.append([key, value])
+            self.hierarchy[key] = int(value)
 
     def __str__(self):
         s = []
@@ -67,10 +70,8 @@ class Record:
         s.append(self.sccs)
         s.append(self.sunid)
 
-        h=[]
-        for ht in self.hierarchy:
-            h.append("=".join(map(str,ht))) 
-        s.append(",".join(h))
+        s.append(','.join('='.join((key, str(value))) for key, value
+                          in self.hierarchy.iteritems()))
 
         return "\t".join(map(str,s)) + "\n"
 
