@@ -322,11 +322,12 @@ def _read(handle):
         raise ValueError("Unexpected end of stream.")
 
 
-# Everything below is considered obsolete
+# Everything below is deprecated
 
 
 from Bio.ParserSupport import *
 import re
+import Bio
 
 #
 # CONSTANTS
@@ -335,7 +336,7 @@ UG_INDENT=12
 
 class UnigeneSequenceRecord:
     """Store the information for one SEQUENCE line from a Unigene file
-    (OBSOLETE).
+    (DEPRECATED).
 
     Initialize with the text part of the SEQUENCE line, or nothing.
 
@@ -364,11 +365,13 @@ class UnigeneSequenceRecord:
                  cases, they are unspliced transcripts originating
                  from the gene.
 
-    This class is OBSOLETE; please use the read() function in this module
+    This class is DEPRECATED; please use the read() function in this module
     instead.
     """
     
     def __init__(self,text=None):
+        import warnings
+        warnings.warn("Bio.UniGene.UnigeneSequenceRecord is deprecated; please use the read() function in this module instead", Bio.BiopythonDeprecationWarning)
         self.acc = ''
         self.nid = ''
         self.lid = ''
@@ -401,7 +404,7 @@ class UnigeneSequenceRecord:
 
 class UnigeneProtsimRecord:
     """Store the information for one PROTSIM line from a Unigene file
-    (OBSOLETE).
+    (DEPRECATED).
 
     Initialize with the text part of the PROTSIM line, or nothing.
 
@@ -412,11 +415,13 @@ class UnigeneProtsimRecord:
     PCT=         Percent alignment
     ALN=         length of aligned region (aa)
 
-    This class is OBSOLETE; please use the read() function in this module
+    This class is DEPRECATED; please use the read() function in this module
     instead.
     """
 
     def __init__(self,text=None):
+        import warnings
+        warnings.warn("Bio.UniGene.UnigeneProtsimRecord is deprecated; please use the read() function in this module instead", Bio.BiopythonDeprecationWarning)
         self.org = ''
         self.protgi = ''
         self.protid = ''
@@ -439,7 +444,7 @@ class UnigeneProtsimRecord:
 
 class UnigeneSTSRecord:
     """Store the information for one STS line from a Unigene file
-    (OBSOLETE).
+    (DEPRECATED).
 
     Initialize with the text part of the STS line, or nothing.
 
@@ -450,11 +455,13 @@ class UnigeneSTSRecord:
     DSEG=        GDB Dsegment number [optional field]
     UNISTS=      identifier in NCBI's UNISTS database
 
-    This class is OBSOLETE; please use the read() function in this module
+    This class is DEPRECATED; please use the read() function in this module
     instead.
     """
 
     def __init__(self,text=None):
+        import warnings
+        warnings.warn("Bio.UniGene.UnigeneSTSRecord is deprecated; please use the read() function in this module instead", Bio.BiopythonDeprecationWarning)
         self.name = ''
         self.acc = ''
         self.dseg = ''
@@ -475,7 +482,7 @@ class UnigeneSTSRecord:
         
 
 class UnigeneRecord:
-    """Store a Unigene record (OBSOLETE).
+    """Store a Unigene record (DEPRECATED).
 
     Here is what is stored:
     
@@ -498,11 +505,13 @@ class UnigeneRecord:
                                 # Type UnigeneSTSRecord
         self.txmap        = []  # TXMAP entries, array of TXMap entries
 
-    This class is OBSOLETE; please use the read() function in this module
+    This class is DEPRECATED; please use the read() function in this module
     instead.
     """
 
     def __init__(self):
+        import warnings
+        warnings.warn("Bio.UniGene.UnigeneRecord is deprecated; please use the read() function in this module instead", Bio.BiopythonDeprecationWarning)
         self.ID           = ''  # ID line
         self.species      = ''  # Hs, Bt, etc.
         self.title        = ''  # TITLE line
@@ -524,10 +533,12 @@ class UnigeneRecord:
 
 
 class _RecordConsumer(AbstractConsumer):
-    """This class is OBSOLETE; please use the read() function in this module
+    """This class is DEPRECATED; please use the read() function in this module
     instead."""
 
     def __init__(self):
+        import warnings
+        warnings.warn("Bio.UniGene._RecordConsumer is deprecated; please use the read() function in this module instead", Bio.BiopythonDeprecationWarning)
         self.unigene_record = UnigeneRecord()
     def ID(self,line):
         self.unigene_record.ID = self._get_single_entry(line)
@@ -569,12 +580,16 @@ class _RecordConsumer(AbstractConsumer):
     
 
 class _Scanner:
-    """Scans a Unigene Flat File Format file (OBSOLETE).
+    """Scans a Unigene Flat File Format file (DEPRECATED).
 
-    This class is OBSOLETE; please use the read() function in this module
+    This class is DEPRECATED; please use the read() function in this module
     instead.
     """
 
+    def __init__(self):
+        import warnings
+        warnings.warn("Bio.UniGene._Scanner is deprecated; please use the read() function in this module instead", Bio.BiopythonDeprecationWarning)
+
     def feed(self, handle, consumer):
         """feed(self, handle, consumer)
 
@@ -600,10 +615,12 @@ class _Scanner:
 
         
 class RecordParser(AbstractParser):
-    """This class is OBSOLETE; please use the read() function in this module
+    """This class is DEPRECATED; please use the read() function in this module
     instead."""
 
     def __init__(self):
+        import warnings
+        warnings.warn("Bio.UniGene._RecordParser is deprecated; please use the read() function in this module instead", Bio.BiopythonDeprecationWarning)
         self._scanner = _Scanner()
         self._consumer = _RecordConsumer()
 
@@ -616,10 +633,12 @@ class RecordParser(AbstractParser):
         return self._consumer.unigene_record
 
 class Iterator:
-    """This class is OBSOLETE; please use the parse() function in this module
+    """This class is DEPRECATED; please use the parse() function in this module
     instead."""
 
     def __init__(self, handle, parser=None):
+        import warnings
+        warnings.warn("Bio.UniGene.Iterator is deprecated; please use the parse() function in this module instead", Bio.BiopythonDeprecationWarning)
         self._uhandle = File.UndoHandle(handle)
 
     def next(self):
