@@ -3,12 +3,8 @@
 """
 # standard library
 import os
-import copy
 import cStringIO
 
-# Biopython
-from Bio import File
-
 # GenBank stuff to test
 from Bio import GenBank
 from Bio.GenBank import utils
@@ -160,6 +156,7 @@ def t_write_format():
             do_comparison(compare_record, output_record)
 
         cur_handle.close()
+        compare_handle.close()
 
 t_write_format()
 
@@ -181,6 +178,8 @@ def t_cleaning_features():
     assert test_trans.find("\012") == -1, \
       "Did not clean newlines out of the translation"
 
+    handle.close()
+
 print "Testing feature cleaning..."
 t_cleaning_features()
 
@@ -208,6 +207,7 @@ def t_bioformat():
     assert all_records[0].description == \
       "Homo sapiens mRNA full length insert cDNA clone EUROIMAGE 125195.", \
       "Unexpected description: %s" % all_records[0].description
+    test_handle.close()
 
 print "Testing format conversions..."
 # t_bioformat() # XXX this is mucked up right now and still under work
