@@ -202,44 +202,6 @@ test_files = [ \
     ("fastq-solexa", True, 'Quality/solexa_example.fastq', 5),
     ]
 
-# This is a list of two-tuples.  Each tuple contains a
-# list of SeqRecord objects and a description (string)
-test_records = [
-    ([], "zero records"),
-    ([SeqRecord(Seq("CHSMAIKLSSEHNIPSGIANAL",Alphabet.generic_protein), id="Alpha"),
-      SeqRecord(Seq("HNGFTALEGEIHHLTHGEKVAF",Alphabet.generic_protein), id="Gamma"),
-      SeqRecord(Seq("DITHGVG",Alphabet.generic_protein), id="delta")],
-     "three peptides of different lengths"),
-    ([SeqRecord(Seq("CHSMAIKLSSEHNIPSGIANAL",Alphabet.generic_protein), id="Alpha"),
-      SeqRecord(Seq("VHGMAHPLGAFYNTPHGVANAI",Alphabet.generic_protein), id="Beta"),
-      SeqRecord(Seq("HNGFTALEGEIHHLTHGEKVAF",Alphabet.generic_protein), id="Gamma")],
-     "three proteins alignment"),
-    ([SeqRecord(Seq("AATAAACCTTGCTGGCCATTGTGATCCATCCA",Alphabet.generic_dna), id="X"),
-      SeqRecord(Seq("ACTCAACCTTGCTGGTCATTGTGACCCCAGCA",Alphabet.generic_dna), id="Y"),
-      SeqRecord(Seq("TTTCCTCGGAGGCCAATCTGGATCAAGACCAT",Alphabet.generic_dna), id="Z")],
-     "three DNA sequence alignment"),
-    ([SeqRecord(Seq("AATAAACCTTGCTGGCCATTGTGATCCATCCA",Alphabet.generic_dna), id="X",
-                name="The\nMystery\rSequece:\r\nX"),
-      SeqRecord(Seq("ACTCAACCTTGCTGGTCATTGTGACCCCAGCA",Alphabet.generic_dna), id="Y",
-                description="an%sevil\rdescription right\nhere" % os.linesep),
-      SeqRecord(Seq("TTTCCTCGGAGGCCAATCTGGATCAAGACCAT",Alphabet.generic_dna), id="Z")],
-     "3 DNA seq alignment with CR/LF in name/descr"),
-    ([SeqRecord(Seq("CHSMAIKLSSEHNIPSGIANAL",Alphabet.generic_protein), id="Alpha"),
-      SeqRecord(Seq("VHGMAHPLGAFYNTPHGVANAI",Alphabet.generic_protein), id="Beta"),
-      SeqRecord(Seq("VHGMAHPLGAFYNTPHGVANAI",Alphabet.generic_protein), id="Beta"),
-      SeqRecord(Seq("HNGFTALEGEIHHLTHGEKVAF",Alphabet.generic_protein), id="Gamma")],
-     "alignment with repeated record"),
-    ]
-# Meddle with the annotation too:
-assert test_records[4][1] == "3 DNA seq alignment with CR/LF in name/descr"
-# Add a list of strings,
-test_records[4][0][2].annotations["note"] = ["Note%salso" % os.linesep \
-                                    + "\r\nhas\n evil line\rbreaks!", "Wow"]
-# Add a simple string
-test_records[4][0][2].annotations["comment"] = "More%sof" % os.linesep \
-                                          + "\r\nthese\n evil line\rbreaks!"
-# Add a float too:
-test_records[4][0][2].annotations["weight"] = 2.5
 
 def compare_record(record_one, record_two):
     """This is meant to be a strict comparison for exact agreement..."""
@@ -609,70 +571,3 @@ for (t_format, t_alignment, t_filename, t_count) in test_files:
     check_simple_write_read(records)
 
 print "Finished tested reading files"
-print
-print "Starting testing writing records"
-print "(Note that some of these are expected to 'fail' and say why)"
-print
-for (records, descr) in test_records:
-    print "Testing can write/read %s" % descr
-    for format in test_write_read_alignment_formats:
-        print " Checking can write/read as '%s' format" % format
-
-        #################
-        # Write records #
-        #################
-        if format in SeqIO._BinaryFormats:
-            handle = BytesIO()
-        else:
-            handle = StringIO()
-        try:
-            c = SeqIO.write(records, handle, format)
-            assert c == len(records)
-        except ValueError, e:
-            #This is expected to happen on many of the examples.
-            print " Failed: %s" % str(e)
-            continue #goto next test
-
-        #################
-        # Read records  #
-        #################
-        handle.seek(0)
-        try:
-            new_records = list(SeqIO.parse(handle, format))
-        except ValueError, e:
-            #THIS INDICATES A SIGNIFICANT PROBLEM,
-            #as we can't read the file we just wrote!
-            print " FAILED: %s" % str(e)
-            continue #goto next test
-
-        #################
-        # Check records #
-        #################
-        assert len(new_records) == len(records)
-        for record, new_record in zip(records, new_records):
-            if format == "nexus":
-                #The nexus parser will dis-ambiguate repeated record ids.
-                assert record.id == new_record.id or \
-                       new_record.id.startswith(record.id+".copy")
-            else:
-                assert record.id == new_record.id
-            assert record.seq.tostring() == new_record.seq.tostring()
-            #Using compare_record(record, new_record) is too strict
-
-        #Close now, after checking, so that it can be used at the console for debugging
-        handle.close()
-
-#Check writers can cope with no alignments
-for format in SeqIO._FormatToWriter:
-    if format in SeqIO._BinaryFormats:
-        handle = BytesIO()
-    else:
-        handle = StringIO()
-    try :
-        assert 0 == SeqIO.write([], handle, format), \
-               "Writing no records to %s format should work!" \
-               % t_format
-    except ValueError, err:
-        print "Writing no records to %s format failed: %s" % (format, err)
-
-print "Finished tested writing files"
