@@ -1,4 +1,4 @@
-# Copyright 2009 by Peter Cock.  All rights reserved.
+# Copyright 2009-2010 by Peter Cock.  All rights reserved.
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
@@ -7,12 +7,19 @@
 import os
 import unittest
 import warnings
+
+from StringIO import StringIO
+try:
+    #This is in Python 2.6+, but we need it on Python 3
+    from io import BytesIO
+except ImportError:
+    BytesIO = StringIO
+
 from Bio.Alphabet import generic_dna
 from Bio.SeqIO import QualityIO
 from Bio import SeqIO
 from Bio.Seq import Seq, UnknownSeq, MutableSeq
 from Bio.SeqRecord import SeqRecord
-from StringIO import StringIO
 from Bio.Data.IUPACData import ambiguous_dna_letters, ambiguous_rna_letters
 
 BINARY_FORMATS = ["sff", "sff-trim"]
@@ -30,11 +37,14 @@ def truncation_expected(format):
 def write_read(filename, in_format, out_format):
     if in_format in BINARY_FORMATS:
         mode = "rb"
-    else :
+    else:
         mode = "r"
     records = list(SeqIO.parse(open(filename, mode),in_format))
     #Write it out...
-    handle = StringIO()
+    if out_format in BINARY_FORMATS:
+        handle = BytesIO()
+    else :
+        handle = StringIO()
     SeqIO.write(records, handle, out_format)
     handle.seek(0)
     #Now load it back and check it agrees,
@@ -118,9 +128,6 @@ def compare_records(old_list, new_list, truncate_qual=None):
 
 class TestFastqErrors(unittest.TestCase):
     """Test reject invalid FASTQ files."""
-    def setUp(self):
-        warnings.resetwarnings()
-
     def check_fails(self, filename, good_count, formats=None, raw=True):
         if not formats:
             formats = ["fastq-sanger", "fastq-solexa", "fastq-illumina"]
@@ -129,7 +136,7 @@ class TestFastqErrors(unittest.TestCase):
             records = SeqIO.parse(handle, format)
             for i in range(good_count):
                 record = records.next() #Make sure no errors!
-                self.assert_(isinstance(record, SeqRecord))
+                self.assertTrue(isinstance(record, SeqRecord))
             self.assertRaises(ValueError, records.next)
             handle.close()
 
@@ -262,14 +269,12 @@ class TestReferenceFastqConversions(unittest.TestCase):
     """Tests where we have reference output."""
     def simple_check(self, base_name, in_variant):
         for out_variant in ["sanger", "solexa", "illumina"]:
-            if out_variant == "sanger":
-                warnings.resetwarnings()
-            else:
+            if out_variant != "sanger":
                 #Ignore data loss warnings from max qualities
                 warnings.simplefilter('ignore', UserWarning)
             in_filename = "Quality/%s_original_%s.fastq" \
                           % (base_name, in_variant)
-            self.assert_(os.path.isfile(in_filename))
+            self.assertTrue(os.path.isfile(in_filename))
             #Load the reference output...  
             expected = open("Quality/%s_as_%s.fastq" \
                             % (base_name, out_variant),
@@ -284,6 +289,9 @@ class TestReferenceFastqConversions(unittest.TestCase):
             SeqIO.write(SeqIO.parse(open(in_filename), "fastq-"+in_variant),
                         handle, "fastq-"+out_variant)
             self.assertEqual(expected, handle.getvalue())
+            if out_variant != "sanger":
+                warnings.filters.pop()
+
 #Now add methods at run time...
 tests = [("illumina_full_range", "illumina"),
          ("sanger_full_range", "sanger"),
@@ -304,23 +312,20 @@ for base_name, variant in tests:
 
 class TestQual(unittest.TestCase):
     """Tests with QUAL files."""
-    def setUp(self):
-        warnings.resetwarnings()
-
     def test_paired(self):
         """Check FASTQ parsing matches FASTA+QUAL parsing"""
         records1 = list(\
             QualityIO.PairedFastaQualIterator(open("Quality/example.fasta"),
                                               open("Quality/example.qual")))
         records2 = list(SeqIO.parse(open("Quality/example.fastq"),"fastq"))
-        self.assert_(compare_records(records1, records2))
+        self.assertTrue(compare_records(records1, records2))
 
     def test_qual(self):
         """Check FASTQ parsing matches QUAL parsing"""
         records1 = list(SeqIO.parse(open("Quality/example.qual"),"qual"))
         records2 = list(SeqIO.parse(open("Quality/example.fastq"),"fastq"))
         #Will ignore the unknown sequences :)
-        self.assert_(compare_records(records1, records2))
+        self.assertTrue(compare_records(records1, records2))
 
     def test_qual_out(self):
         """Check FASTQ to QUAL output"""
@@ -333,7 +338,7 @@ class TestQual(unittest.TestCase):
         """Check FASTQ parsing matches FASTA parsing"""
         records1 = list(SeqIO.parse(open("Quality/example.fasta"),"fasta"))
         records2 = list(SeqIO.parse(open("Quality/example.fastq"),"fastq"))
-        self.assert_(compare_records(records1, records2))
+        self.assertTrue(compare_records(records1, records2))
 
     def test_fasta_out(self):
         """Check FASTQ to FASTA output"""
@@ -345,9 +350,6 @@ class TestQual(unittest.TestCase):
 
 class TestReadWrite(unittest.TestCase):
     """Test can read and write back files."""
-    def setUp(self):
-        warnings.resetwarnings()
-
     def test_fastq_2000(self):
         """Read and write back simple example with upper case 2000bp read"""
         data = "@%s\n%s\n+\n%s\n" \
@@ -405,9 +407,6 @@ class TestReadWrite(unittest.TestCase):
 
 class TestWriteRead(unittest.TestCase):
     """Test can write and read back files."""
-    def setUp(self):
-        warnings.resetwarnings()
-
     def test_generated(self):
         """Write and read back odd SeqRecord objects"""
         record1 = SeqRecord(Seq("ACGT"*500, generic_dna),  id="Test", description="Long "*500,
@@ -438,6 +437,7 @@ class TestWriteRead(unittest.TestCase):
             compare_records(records,
                             list(SeqIO.parse(handle, format)),
                             truncation_expected(format))
+        warnings.filters.pop()
             
     def check(self, filename, format, out_formats):
         for f in out_formats:
@@ -458,6 +458,7 @@ class TestWriteRead(unittest.TestCase):
         warnings.simplefilter('ignore', UserWarning)
         self.check(os.path.join("Quality", "sanger_93.fastq"), "fastq",
                    ["fastq-solexa","fastq-illumina"])
+        warnings.filters.pop()
 
     def test_sanger_faked(self):
         """Write and read back sanger_faked.fastq"""
@@ -562,9 +563,6 @@ class TestWriteRead(unittest.TestCase):
 
 
 class MappingTests(unittest.TestCase):
-    def setUp(self):
-        warnings.resetwarnings()
-
     def test_solexa_quality_from_phred(self):
         """Mapping check for function solexa_quality_from_phred"""
         self.assertEqual(-5, round(QualityIO.solexa_quality_from_phred(0)))
@@ -616,7 +614,7 @@ class MappingTests(unittest.TestCase):
         warnings.simplefilter('ignore', UserWarning)
         SeqIO.write(SeqIO.parse(in_handle, "fastq-sanger"),
                     out_handle, "fastq-solexa")
-        warnings.resetwarnings()
+        warnings.filters.pop()
         out_handle.seek(0)
         record = SeqIO.read(out_handle, "fastq-solexa")
         self.assertEqual(str(record.seq), seq)
@@ -639,7 +637,7 @@ class MappingTests(unittest.TestCase):
         warnings.simplefilter('ignore', UserWarning)
         SeqIO.write(SeqIO.parse(in_handle, "fastq-solexa"),
                     out_handle, "fastq-sanger")
-        warnings.resetwarnings()
+        warnings.filters.pop()
         out_handle.seek(0)
         record = SeqIO.read(out_handle, "fastq-sanger")
         self.assertEqual(str(record.seq), seq)
@@ -658,7 +656,7 @@ class MappingTests(unittest.TestCase):
         warnings.simplefilter('ignore', UserWarning)
         SeqIO.write(SeqIO.parse(in_handle, "fastq-sanger"),
                     out_handle, "fastq-illumina")
-        warnings.resetwarnings()
+        warnings.filters.pop()
         out_handle.seek(0)
         record = SeqIO.read(out_handle, "fastq-illumina")
         self.assertEqual(str(record.seq), seq)
