@@ -19,7 +19,8 @@ for i in ftab_prot.alphabet.letters:
     f.write("%s %f\n" % (i, abs(ftab_prot[i] - ctab_prot[i])))
 
 pickle_file = os.path.join('SubsMat', 'acc_rep_mat.pik')
-acc_rep_mat = cPickle.load(open(pickle_file))
+#Don't want to use text mode on Python 3,
+acc_rep_mat = cPickle.load(open(pickle_file, 'rb'))
 acc_rep_mat = SubsMat.AcceptedReplacementsMatrix(acc_rep_mat)
 obs_freq_mat = SubsMat._build_obs_freq_mat(acc_rep_mat)
 ftab_prot2 = SubsMat._exp_freq_table_from_obs_freq(obs_freq_mat)
