@@ -12,6 +12,9 @@ from cStringIO import StringIO
 from Bio import AlignIO, SeqIO, MissingExternalDependencyError
 from Bio.Align.Applications import TCoffeeCommandline
 
+#Try to avoid problems when the OS is in another language
+os.environ['LANG'] = 'C'
+
 t_coffee_exe = None
 if sys.platform=="win32":
     raise MissingExternalDependencyError(\
@@ -27,7 +30,7 @@ if not t_coffee_exe:
     raise MissingExternalDependencyError(\
         "Install TCOFFEE if you want to use the Bio.Align.Applications wrapper.")
 
-class ProbconsApplication(unittest.TestCase):
+class TCoffeeApplication(unittest.TestCase):
 
     def setUp(self):
         self.infile1 = "Fasta/fa01"
@@ -51,20 +54,14 @@ class ProbconsApplication(unittest.TestCase):
         """
         cmdline = TCoffeeCommandline(t_coffee_exe, infile=self.infile1)
         self.assertEqual(str(cmdline), t_coffee_exe + " -infile Fasta/fa01")
-        child = subprocess.Popen(str(cmdline),
-                                 stdout=subprocess.PIPE,
-                                 stderr=subprocess.PIPE,
-                                 shell=(sys.platform!="win32"))
-        return_code = child.wait()
-        self.assertEqual(return_code, 0)
-        self.assert_(child.stderr.read().strip().startswith("PROGRAM: T-COFFEE"))
+        stdout, stderr = cmdline()
+        self.assertTrue(stderr.strip().startswith("PROGRAM: T-COFFEE"))
         align = AlignIO.read(open(self.outfile1), "clustal")
         records = list(SeqIO.parse(open(self.infile1),"fasta"))
         self.assertEqual(len(records),len(align))
         for old, new in zip(records, align):
             self.assertEqual(old.id, new.id)
             self.assertEqual(str(new.seq).replace("-",""), str(old.seq).replace("-",""))
-        del child
 
     def test_TCoffee_2(self):
         """Round-trip through app and read pir alignment from file
@@ -75,20 +72,15 @@ class ProbconsApplication(unittest.TestCase):
         cmdline.output = "pir_aln"
         self.assertEqual(str(cmdline), t_coffee_exe + " -output pir_aln "
                     "-infile Fasta/fa01 -outfile Fasta/tc_out.pir -quiet")
-        child = subprocess.Popen(str(cmdline),
-                                 stdout=subprocess.PIPE,
-                                 stderr=subprocess.PIPE,
-                                 shell=(sys.platform!="win32"))
-        return_code = child.wait()
-        self.assertEqual(return_code, 0)
-        self.assertEquals(child.stderr.read(), "")
+        stdout, stderr = cmdline()
+        #Can get warnings in stderr output
+        self.assertTrue("error" not in stderr.lower(), stderr)
         align = AlignIO.read(open(self.outfile3), "pir")
         records = list(SeqIO.parse(open(self.infile1),"fasta"))
         self.assertEqual(len(records),len(align))
         for old, new in zip(records, align):
             self.assertEqual(old.id, new.id)
             self.assertEqual(str(new.seq).replace("-",""), str(old.seq).replace("-",""))
-        del child
 
     def test_TCoffee_3(self):
         """Round-trip through app and read clustalw alignment from file
@@ -103,20 +95,14 @@ class ProbconsApplication(unittest.TestCase):
         self.assertEqual(str(cmdline), t_coffee_exe + " -output clustalw_aln "
                          "-infile Fasta/fa01 -outfile Fasta/tc_out.phy "
                          "-type protein -outorder input -gapopen -2 -gapext -5")
-        child = subprocess.Popen(str(cmdline),
-                                 stdout=subprocess.PIPE,
-                                 stderr=subprocess.PIPE,
-                                 shell=(sys.platform!="win32"))
-        return_code = child.wait()
-        self.assertEqual(return_code, 0)
-        self.assert_(child.stderr.read().strip().startswith("PROGRAM: T-COFFEE"))
+        stdout, stderr = cmdline()
+        self.assertTrue(stderr.strip().startswith("PROGRAM: T-COFFEE"))
         align = AlignIO.read(open(self.outfile4), "clustal")
         records = list(SeqIO.parse(open(self.infile1),"fasta"))
         self.assertEqual(len(records),len(align))
         for old, new in zip(records, align):
             self.assertEqual(old.id, new.id)
             self.assertEqual(str(new.seq).replace("-",""), str(old.seq).replace("-",""))
-        del child
 
 if __name__ == "__main__":
     runner = unittest.TextTestRunner(verbosity = 2)
